## Bulk-Sender Application

This is an example application that shows how to build or implement the retarus sms sdk into your environment. Also this application is production ready and can be used to dispatch messages to your customers. So change the path to your csv files and start sending your message to the world.
